==> dcoupon_sdk_flutter_package-5.1.0.tar.gz: lib/src/data/helpers/third_party_api_helper.dart <==
import 'package:dcoupon_sdk_flutter_package/src/config_reader.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/helpers/authorization_helper.dart';
import 'package:dcoupon_sdk_flutter_package/src/utils/constants.dart';
import 'package:dcoupon_sdk_flutter_package/src/utils/enum_helper.dart';

const String VERSION = "v4";

const Map<String, String> URLS_BY_ENVIRONMENT = {
  'local': 'http://localhost:3000/local/',
  'test': 'https://testapi.dcoupon.com/thirdparty/',
  'dev': 'https://services-dev.dcoupon.com/thirdparty/',
  'dcoupon.eu': 'https://services.dcoupon.eu/thirdparty/',
  'dcoupon.com': 'https://services.dcoupon.com/thirdparty/'
};

class ThirdPartyAPIHelper {
  static Map<String, dynamic> buildHeaders({
    AuthMethod authMethod = AuthMethod.SIGNATURE,
    String? jwt,
  }) {
    var headers = <String, dynamic>{};

    final currentDateFormatted = AuthorizationHelper.getCurrentDateFormatted();

    headers[Constants.HEADER_AUTH_METHOD] = EnumHelper.enumToString(authMethod);
    headers[Constants.HEADER_AUTH_TIMESTAMP] = currentDateFormatted;
    headers[Constants.HEADER_AUTH_APIKEY] = ConfigReader.clientApiToken;

    switch (authMethod) {
      case AuthMethod.SIGNATURE:
        headers[Constants.HEADER_AUTH_SIGNATURE] =
            AuthorizationHelper.getAuthSignature(currentDateFormatted);
        break;
      case AuthMethod.JWT:
        headers[Constants.HEADER_AUTH_SIGNATURE] = jwt;
        break;
    }

    return headers;
  }

  static String loginUrl() {
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain!]! +
        VERSION +
        "/login" ;
  }

  static String acceptEnrollmentFormUrl() {
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain!]! +
        VERSION +
        "/accept-enrollment";
  }
}

==> dcoupon_sdk_flutter_package-7.0.1.tar.gz: lib/src/data/helpers/third_party_api_helper.dart <==
import 'package:dcoupon_sdk_flutter_package/src/config_reader.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/device_info.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/helpers/authorization_helper.dart';
import 'package:dcoupon_sdk_flutter_package/src/utils/constants.dart';
import 'package:dcoupon_sdk_flutter_package/src/utils/enum_helper.dart';

const String VERSION = "v4";

const String API_PATH_NAME = '/thirdparty';

const Map<String, String> URLS_BY_ENVIRONMENT = {
  'dev': 'https://services-dev.dcoupon.com',
  'dcoupon.eu': 'https://services.dcoupon.eu',
  'dcoupon.com': 'https://services.dcoupon.com'
};

class ThirdPartyAPIHelper {
  static Map<String, dynamic> buildHeaders({
    AuthMethod authMethod = AuthMethod.SIGNATURE,
    String? jwt,
  }) {
    var headers = <String, dynamic>{};

    final currentDateFormatted = AuthorizationHelper.getCurrentDateFormatted();

    headers[Constants.HEADER_AUTH_METHOD] = EnumHelper.enumToString(authMethod);
    headers[Constants.HEADER_AUTH_TIMESTAMP] = currentDateFormatted;
    headers[Constants.HEADER_AUTH_APIKEY] = ConfigReader.clientApiToken;

    switch (authMethod) {
      case AuthMethod.SIGNATURE:
        headers[Constants.HEADER_AUTH_SIGNATURE] =
            AuthorizationHelper.getAuthSignature(currentDateFormatted);
        break;
      case AuthMethod.JWT:
        headers[Constants.HEADER_AUTH_SIGNATURE] = jwt;
        break;
    }

    return headers;
  }

  static String getEndpointUrl() {
    if (DevicePlatform.isWeb && ConfigReader.webOrigin != null) {
      return ConfigReader.webOrigin!;
    }
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain!]!;
  }

  static String loginUrl() {
    const methodPath = '/$VERSION/login';
    return getEndpointUrl() + API_PATH_NAME + methodPath;

  }

  static String acceptEnrollmentFormUrl() {
    const methodPath = '/$VERSION/accept-enrollment';
    return getEndpointUrl() + API_PATH_NAME + methodPath;
  }
}
